@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 2008-2019 VMware, Inc. All rights reserved.
+ * Copyright (C) 2008-2019,2022 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -174,6 +174,9 @@ AppUtilCollectNamedIcons(GPtrArray *pixbufs,   // IN/OUT
           */
          iconSearchNameSize = strlen(iconName) + 1;
          iconSearchName = g_alloca(iconSearchNameSize);
+
+         /* Ignore return, returns length of the source string */
+         /* coverity[check_return] */
          g_strlcpy(iconSearchName, iconName, iconSearchNameSize);
 
          myIconName = NULL;
@@ -489,10 +492,6 @@ AppUtil_CollectIconArray(const char *iconName,        // IN
             GdkPixbuf *pixbuf;
             int width;
             int height;
-            int x;
-            int y;
-            int rowstride;
-            guchar *pixels;
 
             ASSERT((nitems - i) >= 2);
             width = value[i];
@@ -500,8 +499,10 @@ AppUtil_CollectIconArray(const char *iconName,        // IN
             i += 2;
             pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB, TRUE, 8, width, height);
             if (pixbuf) {
-               pixels = gdk_pixbuf_get_pixels(pixbuf);
-               rowstride = gdk_pixbuf_get_rowstride(pixbuf);
+               int x;
+               int y;
+               int rowstride = gdk_pixbuf_get_rowstride(pixbuf);
+               guchar *pixels = gdk_pixbuf_get_pixels(pixbuf);
 
                for (y = 0; y < height; y++) {
                   for (x = 0; x < width && i < nitems; x++, i++) {
@@ -771,7 +772,7 @@ AppUtil_AppIsSkippable(const char *appName)
  *      Path, or NULL if not available
  *
  * Side effects:
- *      Allocated memory is returned 
+ *      Allocated memory is returned
  *
  *-----------------------------------------------------------------------------
  */
