@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 1998-2019 VMware, Inc. All rights reserved.
+ * Copyright (C) 1998-2022 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -66,8 +66,10 @@
 #include "hostinfo.h"
 #include "hostType.h"
 #include "vm_atomic.h"
+#include "vm_basic_asm.h"
 #include "fileLock.h"
 #include "userlock.h"
+#include "strutil.h"
 
 #include "unicodeOperations.h"
 
@@ -114,8 +116,8 @@ File_Exists(const char *pathName)  // IN: May be NULL.
  *      Errno/GetLastError is available upon failure.
  *
  * Results:
- *      Return 0 if the unlink is successful or if the file did not exist.
- *      Otherwise return -1.
+ *        0  success
+ *      > 0  failure (errno)
  *
  * Side effects:
  *      May unlink the file.
@@ -126,13 +128,13 @@ File_Exists(const char *pathName)  // IN: May be NULL.
 int
 File_UnlinkIfExists(const char *pathName)  // IN:
 {
-   int ret = FileDeletion(pathName, TRUE);
+   errno = FileDeletion(pathName, TRUE);
 
-   if (ret != 0) {
-      ret = (ret == ENOENT) ? 0 : -1;
+   if (errno == ENOENT) {
+      errno = 0;
    }
 
-   return ret;
+   return errno;
 }
 
 
@@ -257,7 +259,8 @@ File_GetFilePermissions(const char *pathName,  // IN:
  *      Errno/GetLastError is available upon failure.
  *
  * Results:
- *      Return 0 if the unlink is successful. Otherwise, returns -1.
+ *        0  success
+ *      > 0  failure (errno)
  *
  * Side effects:
  *      The file is removed.
@@ -268,7 +271,9 @@ File_GetFilePermissions(const char *pathName,  // IN:
 int
 File_Unlink(const char *pathName)  // IN:
 {
-   return (FileDeletion(pathName, TRUE) == 0) ? 0 : -1;
+   errno = FileDeletion(pathName, TRUE);
+
+   return errno;
 }
 
 
@@ -284,7 +289,8 @@ File_Unlink(const char *pathName)  // IN:
  *      Errno/GetLastError is available upon failure.
  *
  * Results:
- *      Return 0 if the unlink is successful. Otherwise, returns -1.
+ *        0  success
+ *      > 0  failure (errno)
  *
  * Side effects:
  *      The file is removed.
@@ -295,7 +301,9 @@ File_Unlink(const char *pathName)  // IN:
 int
 File_UnlinkNoFollow(const char *pathName)  // IN:
 {
-   return (FileDeletion(pathName, FALSE) == 0) ? 0 : -1;
+   errno = FileDeletion(pathName, FALSE);
+
+   return errno;
 }
 
 
@@ -307,7 +315,8 @@ File_UnlinkNoFollow(const char *pathName)  // IN:
  *      Unlink the file, retrying on EBUSY on ESX, up to given timeout.
  *
  * Results:
- *      Return 0 if the unlink is successful. Otherwise, return -1.
+ *        0  success
+ *      > 0  failure (errno)
  *
  * Side effects:
  *      The file is removed.
@@ -319,26 +328,27 @@ int
 File_UnlinkRetry(const char *pathName,       // IN:
                  uint32 maxWaitTimeMilliSec) // IN:
 {
-   int ret;
-
    if (vmx86_server) {
       uint32 const unlinkWait = 300;
       uint32 waitMilliSec = 0;
 
       do {
-         ret = FileDeletion(pathName, TRUE);
-         if (ret != EBUSY || waitMilliSec >= maxWaitTimeMilliSec) {
+         errno = FileDeletion(pathName, TRUE);
+
+         if (errno != EBUSY || waitMilliSec >= maxWaitTimeMilliSec) {
             break;
          }
+
          Log(LGPFX" %s: %s after %u ms\n", __FUNCTION__, pathName, unlinkWait);
+
          Util_Usleep(unlinkWait * 1000);
          waitMilliSec += unlinkWait;
       } while (TRUE);
    } else {
-      ret = FileDeletion(pathName, TRUE);
+      errno = FileDeletion(pathName, TRUE);
    }
 
-   return ret == 0 ? 0 : -1;
+   return errno;
 }
 
 
@@ -1299,7 +1309,7 @@ File_Move(const char *oldFile,  // IN:
       }
    }
 
-   if (asRename) {
+   if (asRename != NULL) {
       *asRename = duringRename;
    }
 
@@ -1330,7 +1340,9 @@ File_Move(const char *oldFile,  // IN:
  *
  * Side effects:
  *    - Deletes the originating directory
- *    - In the event of a failed copy we'll leave the new directory in a state
+ *    - In the event of a failed copy we'll leave the new directory in an
+ *      undefined state. Calling File_DeleteDirectoryContent would be a
+ *      good idea.
  *
  *-----------------------------------------------------------------------------
  */
@@ -1347,7 +1359,7 @@ File_MoveTree(const char *srcName,    // IN:
    ASSERT(srcName != NULL);
    ASSERT(dstName != NULL);
 
-   if (asMove) {
+   if (asMove != NULL) {
       *asMove = FALSE;
    }
 
@@ -1360,7 +1372,7 @@ File_MoveTree(const char *srcName,    // IN:
    }
 
    if (File_Rename(srcName, dstName) == 0) {
-      if (asMove) {
+      if (asMove != NULL) {
          *asMove = TRUE;
       }
 
@@ -1403,15 +1415,14 @@ File_MoveTree(const char *srcName,    // IN:
        */
       if (createdDir) {
          /*
-          * Check for free space on destination filesystem.
-          * We only check for free space if the destination directory
-          * did not exist. In this case, we will not be overwriting any existing
-          * paths, so we need as much space as srcName.
+          * Check for free space on destination filesystem. We only check for
+          * free space if the destination directory did not exist. In this
+          * case, we will not be overwriting any existing paths, so we need as
+          * much space as srcName.
           */
-         int64 srcSize;
-         int64 freeSpace;
-         srcSize = File_GetSizeEx(srcName);
-         freeSpace = File_GetFreeSpace(dstName, TRUE);
+         int64 srcSize = File_GetSizeEx(srcName);
+         int64 freeSpace = File_GetFreeSpace(dstName, TRUE);
+
          if (freeSpace < srcSize) {
             char *spaceStr = Msg_FormatSizeInBytes(srcSize);
             Msg_Append(MSGID(File.MoveTree.dst.insufficientSpace)
@@ -1476,9 +1487,7 @@ File_MoveTree(const char *srcName,    // IN:
 char *
 File_GetModTimeString(const char *pathName)  // IN:
 {
-   int64 modTime;
-
-   modTime = File_GetModTime(pathName);
+   int64 modTime = File_GetModTime(pathName);
 
    return (modTime == -1) ? NULL : TimeUtil_GetTimeFormat(modTime, TRUE, TRUE);
 }
@@ -1491,6 +1500,14 @@ File_GetModTimeString(const char *pathName)  // IN:
  *
  *      Get size of file. Try File_GetSizeEx to get size of directory/symlink.
  *
+ *      For performance reasons, whenever a file grows, many file systems elect
+ *      to not update the on-storage inode information until close or when
+ *      forced to write a dirty page. This is done to avoid wasting I/O
+ *      throughput.
+ *
+ *      The only way to determine the exact, up-to-date size of a file is to
+ *      open it and query the file size.
+ *
  * Results:
  *      Size of file or -1.
  *
@@ -1655,7 +1672,7 @@ FileFirstSlashIndex(const char *pathName,     // IN:
    UnicodeIndex firstBS;
 #endif
 
-   ASSERT(pathName);
+   ASSERT(pathName != NULL);
 
    firstFS = Unicode_FindSubstrInRange(pathName, startIndex, -1,
                                        "/", 0, 1);
@@ -1836,11 +1853,10 @@ Bool
 File_CreateDirectoryHierarchy(const char *pathName,   // IN:
                               char **topmostCreated)  // OUT/OPT:
 {
-   return File_CreateDirectoryHierarchyEx(pathName,
-                                          0777,
-                                          topmostCreated);
+   return File_CreateDirectoryHierarchyEx(pathName, 0777, topmostCreated);
 }
 
+
 /*
  *----------------------------------------------------------------------
  *
@@ -1924,17 +1940,23 @@ FileDeleteDirectoryTree(const char *pathName,  // IN: directory to delete
 #if !defined(_WIN32)
          case S_IFLNK:
             /* Delete symlink, not what it points to */
-            if (FileDeletion(curPath, FALSE) != 0) {
+            err = FileDeletion(curPath, FALSE);
+
+            if ((err != 0) && (err != ENOENT)) {
                fileError = Err_Errno();
             }
             break;
 #endif
 
          default:
-            if (FileDeletion(curPath, FALSE) != 0) {
+            err = FileDeletion(curPath, FALSE);
+
+            if ((err != 0) && (err != ENOENT)) {
 #if defined(_WIN32)
                if (File_SetFilePermissions(curPath, S_IWUSR)) {
-                  if (FileDeletion(curPath, FALSE) != 0) {
+                  err = FileDeletion(curPath, FALSE);
+
+                  if ((err != 0) && (err != ENOENT)) {
                      fileError = Err_Errno();
                   }
                } else {
@@ -1947,9 +1969,11 @@ FileDeleteDirectoryTree(const char *pathName,  // IN: directory to delete
             break;
          }
       } else {
-         fileError = Err_Errno();
-         Log(LGPFX" %s: Lstat of '%s' failed, errno = %d\n",
-             __FUNCTION__, curPath, errno);
+         if (errno != ENOENT) {
+            fileError = Err_Errno();
+            Log(LGPFX" %s: Lstat of '%s' failed, errno = %d\n",
+                __FUNCTION__, curPath, errno);
+         }
       }
 
       Posix_Free(curPath);
@@ -2107,7 +2131,7 @@ File_FindFileInSearchPath(const char *fileIn,      // IN:
    sp = Util_SafeStrdup(searchPath);
    tok = strtok_r(sp, FILE_SEARCHPATHTOKEN, &saveptr);
 
-   while (tok) {
+   while (tok != NULL) {
       if (File_IsFullPath(tok)) {
          /* Fully Qualified Path. Use it. */
          cur = Str_SafeAsprintf(NULL, "%s%s%s", tok, DIRSEPS, file);
@@ -2137,7 +2161,7 @@ File_FindFileInSearchPath(const char *fileIn,      // IN:
    }
 
 done:
-   if (cur) {
+   if (cur != NULL) {
       found = TRUE;
 
       if (result) {
@@ -2220,14 +2244,24 @@ File_ExpandAndCheckDir(const char *dirName)  // IN:
 uint32
 FileSimpleRandom(void)
 {
-   static Atomic_Ptr lckStorage;
-   static rqContext *context = NULL;
    uint32 result;
-   MXUserExclLock *lck = MXUser_CreateSingletonExclLock(&lckStorage,
-                                                        "fileSimpleRandomLock",
-                                                        RANK_LEAF);
+   static rqContext *context = NULL;
+   static Atomic_uint32 spinLock = { 0 };
 
-   MXUser_AcquireExclLock(lck);
+   /*
+    * Use a spin lock here since:
+    *
+    *   The chance we'll spin in tiny.
+    *   The time spent under the spin lock is miniscule.
+    *   The time spent under the spin lock is not highly variable.
+    *   We can't get stuck under the spin lock.
+    *   The overhead of a mutex is larger than the time spent under the spin lock.
+    *   It uses much less memory than a mutex.
+    */
+
+   while (Atomic_ReadWrite(&spinLock, 1)) {
+      PAUSE();
+   }
 
    if (UNLIKELY(context == NULL)) {
       uint32 value;
@@ -2244,7 +2278,7 @@ FileSimpleRandom(void)
 
    result = Random_Quick(context);
 
-   MXUser_ReleaseExclLock(lck);
+   Atomic_Write(&spinLock, 0);
 
    return result;
 }
@@ -2256,9 +2290,9 @@ FileSimpleRandom(void)
  * FileSleeper
  *
  *      Sleep for a random amount of time, no less than the specified minimum
- *      and no more than the specified maximum sleep time values. This often
- *      proves useful to "jitter" retries such that multiple threads don't
- *      easily get into resonance performing necessary actions.
+ *      and no more than the specified maximum. This often proves useful to
+ *      "jitter" retries such that multiple threads don't easily get into
+ *      resonance performing necessary actions (e.g. retries).
  *
  * Results:
  *      Somnambulistic behavior; the amount of time slept is returned.
@@ -2354,22 +2388,18 @@ FileRotateByRename(const char *fileName,  // IN: full path to file
                        Str_SafeAsprintf(NULL, "%s-%d%s", baseName, i - 1, ext);
 
       if (dst == NULL) {
-         result = File_UnlinkIfExists(src);
+         result = FileDeletion(src, FALSE);  // Don't follow a symlink!
 
-         if (result == -1) {
+         if ((result != 0) && (result != ENOENT)) {
             Log(LGPFX" %s: failed to remove %s: %s\n", __FUNCTION__,
-                src, Msg_ErrString());
+                src, Err_Errno2String(Err_Errno()));
          }
       } else {
-         result = Posix_Rename(src, dst);
+         result = File_Rename(src, dst);
 
-         if (result == -1) {
-            int error = Err_Errno();
-
-            if (error != ENOENT) {
-               Log(LGPFX" %s: failed to rename %s -> %s: %s\n", src, dst,
-                   __FUNCTION__, Err_Errno2String(error));
-            }
+         if ((result != 0) && (result != ENOENT)) {
+            Log(LGPFX" %s: rename of %s -> %s failed: %s\n", src, dst,
+                __FUNCTION__, Err_Errno2String(Err_Errno()));
          }
       }
 
@@ -2414,11 +2444,10 @@ FileNumberCompare(const void *a,  // IN:
  * FileRotateByRenumber --
  *
  *      File rotation scheme optimized for vmfs:
- *        1) find highest numbered file (maxNr)
- *        2) rename <base>.<ext> to <base>-<maxNr + 1>.<ext>
- *        3) delete (nFound - numToKeep) lowest numbered files.
- *
- *        Wrap around is handled incorrectly.
+ *        1) Find highest numbered file (maxNr)
+ *        2) Rename <base>.<ext> to <base>-<maxNr + 1>.<ext>
+ *           Should maxNr hit MAX_UINT32, file names are "fixed up".
+ *        3) Delete (nFound - numToKeep) lowest numbered files.
  *
  * Results:
  *      If newFilePath is non-NULL: the new path is returned to *newFilePath
@@ -2439,13 +2468,19 @@ FileRotateByRenumber(const char *filePath,       // IN: full path to file
                      int n,                      // IN: number old files to keep
                      char **newFilePath)         // OUT/OPT: new path to file
 {
-   char *baseDir = NULL, *fmtString = NULL, *baseName = NULL, *tmp;
-   char *fullPathNoExt = NULL;
-   uint32 maxNr = 0;
-   int i, nrFiles, nFound = 0;
-   char **fileList = NULL;
-   uint32 *fileNumbers = NULL;
+   uint32 i;
+   char *tmp;
    int result;
+   int nrFiles;
+   size_t extLen;
+   size_t baseNameLen;
+   uint32 maxNr = 0;
+   uint32 nFound = 0;
+   char *baseDir = NULL;
+   char *baseName = NULL;
+   char **fileList = NULL;
+   char *fullPathNoExt = NULL;
+   uint32 *fileNumbers = NULL;
 
    if (newFilePath != NULL) {
       *newFilePath = NULL;
@@ -2471,7 +2506,7 @@ FileRotateByRenumber(const char *filePath,       // IN: full path to file
       goto cleanup;
    }
 
-   fmtString = Str_SafeAsprintf(NULL, "%s-%%d%s%%n", baseName, ext);
+   baseNameLen = strlen(baseName);
 
    nrFiles = File_ListDirectory(baseDir, &fileList);
    if (nrFiles == -1) {
@@ -2482,17 +2517,35 @@ FileRotateByRenumber(const char *filePath,       // IN: full path to file
 
    fileNumbers = Util_SafeCalloc(nrFiles, sizeof(uint32));
 
+   /*
+    * Make sure the whole file name precisely matches what we expect before
+    * including in the list to be considered.
+    */
+
+   extLen = strlen(ext);
+
    for (i = 0; i < nrFiles; i++) {
-      uint32 curNr;
-      int bytesProcessed = 0;
+      size_t fileNameLen = strlen(fileList[i]);
 
-      /*
-       * Make sure the whole file name matched what we expect for the file.
-       */
+      if ((fileNameLen >= (baseNameLen + 1 /* dash */ + 1 /* digit */ + extLen)) &&
+          (memcmp(fileList[i], baseName, baseNameLen) == 0) &&
+          (fileList[i][baseNameLen] == '-') &&
+          (memcmp(fileList[i] + fileNameLen - extLen, ext, extLen) == 0)) {
+         const char *nr = fileList[i] + baseNameLen + 1;
 
-      if ((sscanf(fileList[i], fmtString, &curNr, &bytesProcessed) >= 1) &&
-          (bytesProcessed == strlen(fileList[i]))) {
-         fileNumbers[nFound++] = curNr;
+         /* No leading zeros; zero is invalid; must be a valid ASCII digit */
+         if ((nr[0] >= '1') && (nr[0] <= '9')) {
+            uint32 curNr;
+            char *endNr = NULL;
+
+            errno = 0;
+            curNr = strtoul(nr, &endNr, 10);
+            if ((errno == 0) &&
+                (endNr == fileList[i] + fileNameLen - extLen) &&
+                (curNr <= MAX_UINT32)) {
+               fileNumbers[nFound++] = curNr;
+            }
+         }
       }
 
       Posix_Free(fileList[i]);
@@ -2501,24 +2554,50 @@ FileRotateByRenumber(const char *filePath,       // IN: full path to file
    if (nFound > 0) {
       qsort(fileNumbers, nFound, sizeof(uint32), FileNumberCompare);
       maxNr = fileNumbers[nFound - 1];
-   }
 
-   /* rename the existing file to the next number */
-   tmp = Str_SafeAsprintf(NULL, "%s/%s-%d%s", baseDir, baseName,
-                          maxNr + 1, ext);
+      /*
+       * If the maximum file number maxes out the uint32 used, rename all of the
+       * files, packing them down to the beginning of the rotation sequence.
+       *
+       * After MAX_UINT32 file rotations we can afford some extra time and I/O
+       * operations to handle the wrapping case nicely.
+       */
 
-   result = Posix_Rename(filePath, tmp);
+      if (maxNr == MAX_UINT32) {
+         for (i = 0; i < nFound; i++) {
+            char *to = Str_SafeAsprintf(NULL, "%s/%s-%u%s", baseDir, baseName,
+                             i + 1, ext);
+            char *from = Str_SafeAsprintf(NULL, "%s/%s-%u%s", baseDir, baseName,
+                             fileNumbers[i], ext);
 
-   if (result == -1) {
-      int error = Err_Errno();
+            result = File_Rename(from, to);
 
-      if (error != ENOENT) {
-         Log(LGPFX" %s: failed to rename %s -> %s failed: %s\n", __FUNCTION__,
-             filePath, tmp, Err_Errno2String(error));
+            if (result != 0) {
+               Log(LGPFX" %s: rename of %s -> %s failed: %s\n", __FUNCTION__,
+                   from, to, Err_Errno2String(Err_Errno()));
+            }
+
+            free(to);
+            free(from);
+
+            fileNumbers[i] = i + 1;
+         }
+
+         maxNr = nFound;
       }
    }
 
-   if (newFilePath == NULL || result == -1) {
+   /* Rename the existing file to the next number */
+   tmp = Str_SafeAsprintf(NULL, "%s/%s-%u%s", baseDir, baseName, maxNr + 1, ext);
+
+   result = File_Rename(filePath, tmp);
+
+   if ((result != 0) && (result != ENOENT)) {
+      Log(LGPFX" %s: rename of %s -> %s failed: %s\n", __FUNCTION__,
+          filePath, tmp, Err_Errno2String(Err_Errno()));
+   }
+
+   if (newFilePath == NULL || result != 0) {
       Posix_Free(tmp);
    } else {
       *newFilePath = tmp;
@@ -2527,13 +2606,16 @@ FileRotateByRenumber(const char *filePath,       // IN: full path to file
    if (nFound >= n) {
       /* Delete the extra files. */
       for (i = 0; i <= nFound - n; i++) {
-         tmp = Str_SafeAsprintf(NULL, "%s/%s-%d%s", baseDir, baseName,
+         tmp = Str_SafeAsprintf(NULL, "%s/%s-%u%s", baseDir, baseName,
                                 fileNumbers[i], ext);
 
-         if (Posix_Unlink(tmp) == -1) {
-            Log(LGPFX" %s: failed to remove %s: %s\n", __FUNCTION__, tmp,
-                Msg_ErrString());
+         result = FileDeletion(tmp, FALSE);  // Don't follow a symlink!
+
+         if (result != 0) {
+            Log(LGPFX" %s: failed to remove %s: %s\n", __FUNCTION__,
+                tmp, Err_Errno2String(Err_Errno()));
          }
+
          Posix_Free(tmp);
       }
    }
@@ -2541,7 +2623,6 @@ FileRotateByRenumber(const char *filePath,       // IN: full path to file
   cleanup:
    Posix_Free(fileNumbers);
    Posix_Free(fileList);
-   Posix_Free(fmtString);
    Posix_Free(baseDir);
    Posix_Free(baseName);
    Posix_Free(fullPathNoExt);
@@ -2684,3 +2765,49 @@ File_ContainSymLink(const char *pathName)  // IN:
 
    return retValue;
 }
+
+
+/*
+ *----------------------------------------------------------------------------
+ *
+ * File_IsSubPathOf --
+ *
+ *    Check if the argument path is a sub path for argument base.
+ *    The argument path will be converted to canonical path which doesn't
+ *    contain ".." and then check if this canonical path is a sub path for
+ *    argument base.
+ *    So, this function can correctly recognize that a path like
+ *    "/tmp/dir1/dir2/../../../bin/" is not a sub path for "/tmp/".
+ *
+ * Results:
+ *    True if the argument path is a sub path for argument base.
+ *
+ * Side effects:
+ *    None.
+ *
+ *----------------------------------------------------------------------------
+ */
+
+Bool
+File_IsSubPathOf(const char *base, // IN: the base path to test against.
+                 const char *path) // IN: the possible subpath to test.
+{
+   char *fullBase = File_FullPath(base);
+   char *fullPath = File_FullPath(path);
+   Bool isSubPath = TRUE;
+
+   ASSERT(fullBase != NULL);
+   ASSERT(fullPath != NULL);
+
+   if (fullPath == NULL ||
+       fullBase == NULL ||
+       strncmp(fullPath, fullBase, strlen(fullBase)) != 0) {
+      isSubPath = FALSE;
+   }
+
+   free(fullBase);
+   free(fullPath);
+
+   return isSubPath;
+}
+
