@@ -1596,6 +1596,13 @@ TOOLS_VERSION_UINT_TO_COMPONENTS(const ToolsVersion toolsVersion,   // IN
 #define   TOOLS_VERSION_JACKHAMMER_PATCH12_V_MNR  3
 #define   TOOLS_VERSION_JACKHAMMER_PATCH12_V_BASE 25
 
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_JACKHAMMER_PATCH13 TOOLS_VERSION_TO_UINT(TOOLS_VERSION_JACKHAMMER_PATCH13_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_JACKHAMMER_PATCH13_V_MJR  10
+#define   TOOLS_VERSION_JACKHAMMER_PATCH13_V_MNR  3
+#define   TOOLS_VERSION_JACKHAMMER_PATCH13_V_BASE 26
+
 #ifndef RC_INVOKED
 #define   TOOLS_VERSION_SLEDGEHAMMER_RELEASE TOOLS_VERSION_TO_UINT(TOOLS_VERSION_SLEDGEHAMMER_RELEASE_V)
 #endif /* RC_INVOKED */
@@ -1708,6 +1715,13 @@ TOOLS_VERSION_UINT_TO_COMPONENTS(const ToolsVersion toolsVersion,   // IN
 #define   TOOLS_VERSION_SABRE_SAW_UPDATE1_V_MNR  0
 #define   TOOLS_VERSION_SABRE_SAW_UPDATE1_V_BASE 5
 
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_SABRE_SAW_PATCH1 TOOLS_VERSION_TO_UINT(TOOLS_VERSION_SABRE_SAW_PATCH1_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_SABRE_SAW_PATCH1_V_MJR  12
+#define   TOOLS_VERSION_SABRE_SAW_PATCH1_V_MNR  0
+#define   TOOLS_VERSION_SABRE_SAW_PATCH1_V_BASE 6
+
 #ifndef RC_INVOKED
 #define   TOOLS_VERSION_MITER_SAW_RELEASE TOOLS_VERSION_TO_UINT(TOOLS_VERSION_MITER_SAW_RELEASE_V)
 #endif /* RC_INVOKED */
@@ -1722,9 +1736,16 @@ TOOLS_VERSION_UINT_TO_COMPONENTS(const ToolsVersion toolsVersion,   // IN
 #define   TOOLS_VERSION_MITER_SAW_UPDATE1_V_MNR  1
 #define   TOOLS_VERSION_MITER_SAW_UPDATE1_V_BASE 5
 
-#define   TOOLS_VERSION_CURRENT        TOOLS_VERSION_MITER_SAW_UPDATE1
-#define   TOOLS_VERSION_CURRENT_STR    TOOLS_VERSION_TO_STR(TOOLS_VERSION_MITER_SAW_UPDATE1)
-#define   TOOLS_VERSION_CURRENT_CSV    TOOLS_VERSION_TO_CSV(TOOLS_VERSION_MITER_SAW_UPDATE1)
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_NEXT TOOLS_VERSION_TO_UINT(TOOLS_VERSION_NEXT_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_NEXT_V_MJR  12
+#define   TOOLS_VERSION_NEXT_V_MNR  2
+#define   TOOLS_VERSION_NEXT_V_BASE 0
+
+#define   TOOLS_VERSION_CURRENT        TOOLS_VERSION_NEXT
+#define   TOOLS_VERSION_CURRENT_STR    TOOLS_VERSION_TO_STR(TOOLS_VERSION_NEXT)
+#define   TOOLS_VERSION_CURRENT_CSV    TOOLS_VERSION_TO_CSV(TOOLS_VERSION_NEXT)
 
 /*
  * The extended Tools version is the current Tools version with the
