@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 2009-2019 VMware, Inc. All rights reserved.
+ * Copyright (C) 2009-2021 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -78,11 +78,13 @@ DnDUIX11::DnDUIX11(ToolsAppCtx *ctx)
     : mCtx(ctx),
       mDnD(NULL),
       mDetWnd(NULL),
+      mClipboard(),
       mBlockCtrl(NULL),
       mHGGetFileStatus(DND_FILE_TRANSFER_NOT_STARTED),
       mBlockAdded(false),
       mGHDnDInProgress(false),
       mGHDnDDataReceived(false),
+      mGHDnDDropOccurred(false),
       mUnityMode(false),
       mInHGDrag(false),
       mEffect(DROP_NONE),
@@ -93,7 +95,9 @@ DnDUIX11::DnDUIX11(ToolsAppCtx *ctx)
       mDestDropTime(0),
       mTotalFileSize(0),
       mOrigin(0, 0),
-      mUseUInput(false)
+      mUseUInput(false),
+      mScreenWidth(0),
+      mScreenHeight(0)
 {
    TRACE_CALL();
 
@@ -463,8 +467,15 @@ DnDUIX11::OnSrcDragBegin(const CPClipboard *clip,       // IN
 #ifndef GTK3
    event.device = gdk_device_get_core_pointer();
 #else
-   GdkDeviceManager* manager = gdk_display_get_device_manager(gdk_window_get_display(event.window));
+#   if GTK_MINOR_VERSION >= 20
+   GdkSeat *seat =
+      gdk_display_get_default_seat(gdk_window_get_display(event.window));
+   event.device = gdk_seat_get_pointer(seat);
+#   else
+   GdkDeviceManager *manager =
+      gdk_display_get_device_manager(gdk_window_get_display(event.window));
    event.device = gdk_device_manager_get_client_pointer(manager);
+#   endif
 #endif
    event.x_root = mOrigin.get_x();
    event.y_root = mOrigin.get_y();
@@ -1079,7 +1090,6 @@ DnDUIX11::OnGtkDragDataGet(
    guint info,                                  // UNUSED
    guint time)                                  // IN: event timestamp
 {
-   size_t index = 0;
    std::string str;
    std::string uriList;
    std::string stagingDirName;
@@ -1105,6 +1115,7 @@ DnDUIX11::OnGtkDragDataGet(
 
    if (   target == DRAG_TARGET_NAME_URI_LIST
        && CPClipboard_GetItem(&mClipboard, CPFORMAT_FILELIST, &buf, &sz)) {
+      size_t index = 0;
 
       /* Provide path within vmblock file system instead of actual path. */
       stagingDirName = GetLastDirName(mHGStagingDir);
@@ -1413,10 +1424,6 @@ DnDUIX11::OnGtkDragDrop(
 bool
 DnDUIX11::SetCPClipboardFromGtk(const Gtk::SelectionData& sd) // IN
 {
-   char *newPath;
-   char *newRelPath;
-   size_t newPathLen;
-   size_t index = 0;
    DnDFileList fileList;
    DynBuf buf;
    uint64 totalSize = 0;
@@ -1431,6 +1438,10 @@ DnDUIX11::SetCPClipboardFromGtk(const Gtk::SelectionData& sd) // IN
        * one for just the last path component.
        */
       utf::string source = sd.get_data_as_string().c_str();
+      size_t index = 0;
+      char *newPath;
+      size_t newPathLen;
+
       g_debug("%s: Got file list: [%s]\n", __FUNCTION__, source.c_str());
 
       if (sd.get_data_as_string().length() == 0) {
@@ -1458,6 +1469,8 @@ DnDUIX11::SetCPClipboardFromGtk(const Gtk::SelectionData& sd) // IN
       while ((newPath = DnD_UriListGetNextFile(source.c_str(),
                                                &index,
                                                &newPathLen)) != NULL) {
+         char *newRelPath;
+
 #if defined(__linux__)
          if (DnD_UriIsNonFileSchemes(newPath)) {
             /* Try to get local file path for non file uri. */
