@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 2008-2019 VMware, Inc. All rights reserved.
+ * Copyright (C) 2008-2020 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -249,7 +249,7 @@ GetCardinal(Glib::RefPtr<const Gdk::Window> window, // IN: Window
 bool
 GetCardinalList(Glib::RefPtr<const Gdk::Window> window, // IN: Window
                 const utf::string& atomName,            // IN: Atom name
-                std::vector<unsigned long>& retValues)         // IN: Return values
+                std::vector<unsigned long>& retValues)  // IN: Return values
 {
    ASSERT(window);
    ASSERT(window->get_display());
@@ -306,6 +306,64 @@ GetCardinalList(Glib::RefPtr<const Gdk::Window> window, // IN: Window
 }
 
 
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * xutils::CheckDockPanel --
+ *
+ *      Utility function to check dock or panel window.
+ *
+ * Results:
+ *      true if the dock or panel window found.
+ *      Otherwise false.
+ *
+ * Side effects:
+ *      None.
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+bool
+CheckDockPanel(Glib::RefPtr<const Gdk::Window> window)
+{
+   ASSERT(window);
+   ASSERT(window->get_display());
+
+   GdkDisplay* display = const_cast<GdkDisplay*>(window->get_display()->gobj());
+   GdkWindow* gdkwin = const_cast<GdkWindow*>(window->gobj());
+
+   Atom atom = gdk_x11_get_xatom_by_name_for_display(display, "_NET_WM_WINDOW_TYPE");
+   Atom type;
+   int format;
+   unsigned long nitems;
+   unsigned long bytes_after;
+   uint8* values;
+
+   gdk_error_trap_push();
+   int ret = XGetWindowProperty(GDK_DISPLAY_XDISPLAY(display),
+                                GDK_WINDOW_XID(gdkwin),
+                                atom, 0, G_MAXLONG, False, AnyPropertyType, &type,
+                                &format, &nitems, &bytes_after, &values);
+   int err = gdk_error_trap_pop();
+   if (err) {
+      Log("Ignore xerror in XGetWindowProperty. Error code %d", err);
+      return false;
+   }
+   if (ret == Success && type == XA_ATOM
+       && format == 32 && values != NULL && nitems > 0) {
+      unsigned long* stack = (unsigned long*)values;
+      if (stack[0] == XInternAtom(GDK_DISPLAY_XDISPLAY(display),
+                                  "_NET_WM_WINDOW_TYPE_DOCK", false)) {
+         Log("found dock window: %ld.\n",GDK_WINDOW_XID(gdkwin));
+         XFree(values);
+         return true;
+      }
+   }
+   XFree(values);
+   return false;
+}
+
+
 /*
  *-----------------------------------------------------------------------------
  *
@@ -989,9 +1047,15 @@ GetMonitorWorkArea(Glib::RefPtr<Gdk::Screen> screen,    // IN:
       std::vector<unsigned long> values;
       NETWMStrutPartial strut = NETWMStrutPartial();
 
+      gdk_error_trap_push();
       if (monitor != screen->get_monitor_at_window(gdkWindow)) {
          continue;
       }
+      int err = gdk_error_trap_pop();
+      if (err) {
+         Log("Ignore xerror in get_monitor_at_window. Error code %d", err);
+         continue;
+      }
 
       /*
        * The EWMH spec says that the new _NET_WM_STRUT_PARTIAL takes precedence
