@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 2012-2017, 2019-2020 VMware, Inc. All rights reserved.
+ * Copyright (C) 2012-2017, 2019-2021 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -1236,10 +1236,10 @@ VGAuth_ReadAndParseResponse(VGAuthContext *ctx,
       if (0 == len) {      // EOF -- not expected
          err = VGAUTH_E_COMM;
          Warning("%s: EOF on datastream when trying to parse\n", __FUNCTION__);
-         goto abort;
+         goto quit;
       }
       if (VGAUTH_E_OK != err) {
-         goto abort;
+         goto quit;
       }
 #if VGAUTH_PROTO_TRACE
       if (reply->rawData) {
@@ -1262,7 +1262,7 @@ VGAuth_ReadAndParseResponse(VGAuthContext *ctx,
          Warning("%s: g_markup_parse_context_parse() failed: %s\n",
                  __FUNCTION__, gErr->message);
          g_error_free(gErr);
-         goto abort;
+         goto quit;
       }
       /*
        * XXX need some way to break out if packet never completed
@@ -1278,7 +1278,7 @@ VGAuth_ReadAndParseResponse(VGAuthContext *ctx,
 
    if (VGAUTH_E_OK != err) {
       Warning("%s: reply sanity check failed\n", __FUNCTION__);
-      goto abort;
+      goto quit;
    }
 
    if (PROTO_REPLY_ERROR == reply->actualReplyType) {
@@ -1289,7 +1289,7 @@ VGAuth_ReadAndParseResponse(VGAuthContext *ctx,
    }
    goto done;
 
-abort:
+quit:
    Proto_FreeReply(reply);
    reply = NULL;
 done:
@@ -1330,13 +1330,13 @@ VGAuth_SendSessionRequest(VGAuthContext *ctx,
    err = VGAuth_CommSendData(ctx, packet);
    if (VGAUTH_E_OK != err) {
       Warning("%s: failed to send packet\n", __FUNCTION__);
-      goto abort;
+      goto quit;
    }
 
    err = VGAuth_ReadAndParseResponse(ctx, PROTO_REPLY_SESSION_REQ, &reply);
    if (VGAUTH_E_OK != err) {
       Warning("%s: read & parse reply failed\n", __FUNCTION__);
-      goto abort;
+      goto quit;
    }
 
    /* version # check */
@@ -1351,7 +1351,7 @@ VGAuth_SendSessionRequest(VGAuthContext *ctx,
 
    ctx->comm.sequenceNumber++;
 
-abort:
+quit:
    Proto_FreeReply(reply);
    g_free(packet);
    return err;
@@ -1497,7 +1497,7 @@ VGAuth_SendAddAliasRequest(VGAuthContext *ctx,
    if (!VGAuth_IsConnectedToServiceAsUser(ctx, userName)) {
       err = VGAuth_ConnectToServiceAsUser(ctx, userName);
       if (VGAUTH_E_OK != err) {
-         goto abort;
+         goto quit;
       }
    }
 
@@ -1522,18 +1522,18 @@ VGAuth_SendAddAliasRequest(VGAuthContext *ctx,
    err = VGAuth_CommSendData(ctx, packet);
    if (VGAUTH_E_OK != err) {
       Warning("%s: failed to send packet\n", __FUNCTION__);
-      goto abort;
+      goto quit;
    }
 
    err = VGAuth_ReadAndParseResponse(ctx, PROTO_REPLY_ADDALIAS, &reply);
    if (VGAUTH_E_OK != err) {
       Warning("%s: read & parse reply failed\n", __FUNCTION__);
-      goto abort;
+      goto quit;
    }
 
    ctx->comm.sequenceNumber++;
 
-abort:
+quit:
    Proto_FreeReply(reply);
    g_free(packet);
    return err;
@@ -1575,14 +1575,14 @@ VGAuth_SendRemoveAliasRequest(VGAuthContext *ctx,
       if (!VGAuth_IsConnectedToServiceAsUser(ctx, userName)) {
          err = VGAuth_ConnectToServiceAsUser(ctx, userName);
          if (VGAUTH_E_OK != err) {
-            goto abort;
+            goto quit;
          }
       }
    } else {
       if (!VGAuth_IsConnectedToServiceAsUser(ctx, SUPERUSER_NAME)) {
          err = VGAuth_ConnectToServiceAsUser(ctx, SUPERUSER_NAME);
          if (VGAUTH_E_OK != err) {
-            goto abort;
+            goto quit;
          }
       }
    }
@@ -1607,18 +1607,18 @@ VGAuth_SendRemoveAliasRequest(VGAuthContext *ctx,
    err = VGAuth_CommSendData(ctx, packet);
    if (VGAUTH_E_OK != err) {
       Warning("%s: failed to send packet\n", __FUNCTION__);
-      goto abort;
+      goto quit;
    }
 
    err = VGAuth_ReadAndParseResponse(ctx, PROTO_REPLY_REMOVEALIAS, &reply);
    if (VGAUTH_E_OK != err) {
       Warning("%s: read & parse reply failed\n", __FUNCTION__);
-      goto abort;
+      goto quit;
    }
 
    ctx->comm.sequenceNumber++;
 
-abort:
+quit:
    Proto_FreeReply(reply);
    g_free(packet);
    return err;
@@ -1663,14 +1663,14 @@ VGAuth_SendQueryUserAliasesRequest(VGAuthContext *ctx,
       if (!VGAuth_IsConnectedToServiceAsUser(ctx, userName)) {
          err = VGAuth_ConnectToServiceAsUser(ctx, userName);
          if (VGAUTH_E_OK != err) {
-            goto abort;
+            goto quit;
          }
       }
    } else {
       if (!VGAuth_IsConnectedToServiceAsUser(ctx, SUPERUSER_NAME)) {
          err = VGAuth_ConnectToServiceAsUser(ctx, SUPERUSER_NAME);
          if (VGAUTH_E_OK != err) {
-            goto abort;
+            goto quit;
          }
       }
    }
@@ -1682,13 +1682,13 @@ VGAuth_SendQueryUserAliasesRequest(VGAuthContext *ctx,
    err = VGAuth_CommSendData(ctx, packet);
    if (VGAUTH_E_OK != err) {
       Warning("%s: failed to send packet\n", __FUNCTION__);
-      goto abort;
+      goto quit;
    }
 
    err = VGAuth_ReadAndParseResponse(ctx, PROTO_REPLY_QUERYALIASES, &reply);
    if (VGAUTH_E_OK != err) {
       Warning("%s: read & parse reply failed\n", __FUNCTION__);
-      goto abort;
+      goto quit;
    }
 
    // just copy the reply data
@@ -1701,7 +1701,7 @@ VGAuth_SendQueryUserAliasesRequest(VGAuthContext *ctx,
 
    ctx->comm.sequenceNumber++;
 
-abort:
+quit:
    Proto_FreeReply(reply);
    g_free(packet);
    return err;
@@ -1742,7 +1742,7 @@ VGAuth_SendQueryMappedAliasesRequest(VGAuthContext *ctx,
    if (!VGAuth_IsConnectedToServiceAsAnyUser(ctx)) {
       err = VGAuth_ConnectToServiceAsCurrentUser(ctx);
       if (VGAUTH_E_OK != err) {
-         goto abort;
+         goto quit;
       }
    }
 
@@ -1752,13 +1752,13 @@ VGAuth_SendQueryMappedAliasesRequest(VGAuthContext *ctx,
    err = VGAuth_CommSendData(ctx, packet);
    if (VGAUTH_E_OK != err) {
       Warning("%s: failed to send packet\n", __FUNCTION__);
-      goto abort;
+      goto quit;
    }
 
    err = VGAuth_ReadAndParseResponse(ctx, PROTO_REPLY_QUERYMAPPEDALIASES, &reply);
    if (VGAUTH_E_OK != err) {
       Warning("%s: read & parse reply failed\n", __FUNCTION__);
-      goto abort;
+      goto quit;
    }
 
    // just copy the reply data
@@ -1771,7 +1771,7 @@ VGAuth_SendQueryMappedAliasesRequest(VGAuthContext *ctx,
 
    ctx->comm.sequenceNumber++;
 
-abort:
+quit:
    Proto_FreeReply(reply);
    g_free(packet);
    return err;
@@ -1811,7 +1811,7 @@ VGAuth_SendCreateTicketRequest(VGAuthContext *ctx,
    if (!VGAuth_IsConnectedToServiceAsUser(ctx, userHandle->userName)) {
       err = VGAuth_ConnectToServiceAsUser(ctx, userHandle->userName);
       if (VGAUTH_E_OK != err) {
-         goto abort;
+         goto quit;
       }
    }
 
@@ -1853,20 +1853,20 @@ VGAuth_SendCreateTicketRequest(VGAuthContext *ctx,
    err = VGAuth_CommSendData(ctx, packet);
    if (VGAUTH_E_OK != err) {
       Warning("%s: failed to send packet\n", __FUNCTION__);
-      goto abort;
+      goto quit;
    }
 
    err = VGAuth_ReadAndParseResponse(ctx, PROTO_REPLY_CREATETICKET, &reply);
    if (VGAUTH_E_OK != err) {
       Warning("%s: read & parse reply failed\n", __FUNCTION__);
-      goto abort;
+      goto quit;
    }
 
    *ticket = g_strdup(reply->replyData.createTicket.ticket);
 
    ctx->comm.sequenceNumber++;
 
-abort:
+quit:
    Proto_FreeReply(reply);
    g_free(packet);
    g_free(tokenInText);
@@ -2089,7 +2089,7 @@ VGAuth_SendValidateSamlBearerTokenRequest(VGAuthContext *ctx,
    if (!VGAuth_IsConnectedToServiceAsAnyUser(ctx)) {
       err = VGAuth_ConnectToServiceAsCurrentUser(ctx);
       if (VGAUTH_E_OK != err) {
-         goto abort;
+         goto quit;
       }
    }
 
@@ -2102,7 +2102,7 @@ VGAuth_SendValidateSamlBearerTokenRequest(VGAuthContext *ctx,
    err = VGAuth_CommSendData(ctx, packet);
    if (VGAUTH_E_OK != err) {
       Warning("%s: failed to send packet\n", __FUNCTION__);
-      goto abort;
+      goto quit;
    }
 
    err = VGAuth_ReadAndParseResponse(ctx,
@@ -2110,7 +2110,7 @@ VGAuth_SendValidateSamlBearerTokenRequest(VGAuthContext *ctx,
                                      &reply);
    if (VGAUTH_E_OK != err) {
       Warning("%s: read & parse reply failed\n", __FUNCTION__);
-      goto abort;
+      goto quit;
    }
 
 
@@ -2118,7 +2118,7 @@ VGAuth_SendValidateSamlBearerTokenRequest(VGAuthContext *ctx,
       hType = VGAUTH_AUTH_TYPE_SAML;
 #ifdef _WIN32
       CHK_TEXT_TO_UINT32(tokenValue, reply->replyData.validateSamlBToken.token,
-                         goto abort);
+                         goto quit);
       token = (HANDLE)(size_t)tokenValue;
 #endif
    } else {
@@ -2131,7 +2131,7 @@ VGAuth_SendValidateSamlBearerTokenRequest(VGAuthContext *ctx,
                                         token, &newHandle);
    if (err != VGAUTH_E_OK) {
       Warning("%s: failed to create userHandle\n", __FUNCTION__);
-      goto abort;
+      goto quit;
    }
 
    /*
@@ -2144,14 +2144,14 @@ VGAuth_SendValidateSamlBearerTokenRequest(VGAuthContext *ctx,
                                       &(reply->replyData.validateSamlBToken.aliasInfo));
    if (err != VGAUTH_E_OK) {
       Warning("%s: failed to set the SAML info on the userHandle\n", __FUNCTION__);
-      goto abort;
+      goto quit;
    }
 
    *userHandle = newHandle;
 
    ctx->comm.sequenceNumber++;
 
-abort:
+quit:
    Proto_FreeReply(reply);
    g_free(packet);
 
